# open-deepresearch
DeepResearch but Open-Sourced

## How to install in DEV environment
```bash
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements.txt
pip install -e .
open_deepresearch
```
